List Available Prebuilt WSS Reference Sets
Value
A character vector of prebuilt reference set names usable as the
prebuilt argument of calculate_WSS() and load_prebuilt_wss().
List Available Prebuilt WSS Reference Sets
A character vector of prebuilt reference set names usable as the
prebuilt argument of calculate_WSS() and load_prebuilt_wss().