Reads one of the module weighting tables shipped with WSSmod. The raw
table may assign the same protein to more than one module (e.g. once per
biomarker it was associated with); calculate_WSS() deduplicates and
filters this table before use via dedup_by and min_module_size.
Arguments
- prebuilt
Name of a prebuilt reference set. See
list_prebuilt_wss()for available options.
Value
A data.table with (at least) columns module, symbol,
mean_beta, and mean_alpha_scaled, suitable for use as the result
argument of calculate_WSS().